==> qore-xml-module-1.5.3.tar.bz2: qore-xml-module-1.5.3/docs/WSDL/html/annotated_dup.js <==
var annotated_dup =
[
    [ "WSDL", "namespace_w_s_d_l.html", [
      [ "WSDLLib", "class_w_s_d_l_1_1_w_s_d_l_lib.html", "class_w_s_d_l_1_1_w_s_d_l_lib" ],
      [ "XsdBase", "class_w_s_d_l_1_1_xsd_base.html", null ],
      [ "XsdData", "class_w_s_d_l_1_1_xsd_data.html", null ],
      [ "XsdNamedData", "class_w_s_d_l_1_1_xsd_named_data.html", "class_w_s_d_l_1_1_xsd_named_data" ],
      [ "XsdBaseType", "class_w_s_d_l_1_1_xsd_base_type.html", null ],
      [ "XsdArrayType", "class_w_s_d_l_1_1_xsd_array_type.html", null ],
      [ "XsdTypedData", "class_w_s_d_l_1_1_xsd_typed_data.html", null ],
      [ "XsdAttribute", "class_w_s_d_l_1_1_xsd_attribute.html", null ],
      [ "XsdElement", "class_w_s_d_l_1_1_xsd_element.html", null ],
      [ "XsdSimpleType", "class_w_s_d_l_1_1_xsd_simple_type.html", null ],
      [ "ChoiceInfo", "struct_w_s_d_l_1_1_choice_info.html", null ],
      [ "XsdComplexType", "class_w_s_d_l_1_1_xsd_complex_type.html", "class_w_s_d_l_1_1_xsd_complex_type" ],
      [ "WSOperation", "class_w_s_d_l_1_1_w_s_operation.html", "class_w_s_d_l_1_1_w_s_operation" ],
      [ "ArgInfo", "struct_w_s_d_l_1_1_arg_info.html", "struct_w_s_d_l_1_1_arg_info" ],
      [ "WSMessage", "class_w_s_d_l_1_1_w_s_message.html", "class_w_s_d_l_1_1_w_s_message" ],
      [ "OperationalBinding", "class_w_s_d_l_1_1_operational_binding.html", null ],
      [ "BindingMessageBodyDescription", "class_w_s_d_l_1_1_binding_message_body_description.html", "class_w_s_d_l_1_1_binding_message_body_description" ],
      [ "BindingMessageHeaderDescription", "class_w_s_d_l_1_1_binding_message_header_description.html", "class_w_s_d_l_1_1_binding_message_header_description" ],
      [ "BindingContentDescription", "class_w_s_d_l_1_1_binding_content_description.html", "class_w_s_d_l_1_1_binding_content_description" ],
      [ "MimeXmlMessageDescription", "class_w_s_d_l_1_1_mime_xml_message_description.html", "class_w_s_d_l_1_1_mime_xml_message_description" ],
      [ "BindingMessageDescription", "class_w_s_d_l_1_1_binding_message_description.html", "class_w_s_d_l_1_1_binding_message_description" ],
      [ "Binding", "class_w_s_d_l_1_1_binding.html", "class_w_s_d_l_1_1_binding" ],
      [ "Namespaces", "class_w_s_d_l_1_1_namespaces.html", "class_w_s_d_l_1_1_namespaces" ],
      [ "PortTypeInfo", "struct_w_s_d_l_1_1_port_type_info.html", null ],
      [ "ServiceInfo", "struct_w_s_d_l_1_1_service_info.html", "struct_w_s_d_l_1_1_service_info" ],
      [ "OperationInfo", "struct_w_s_d_l_1_1_operation_info.html", "struct_w_s_d_l_1_1_operation_info" ],
      [ "WebService", "class_w_s_d_l_1_1_web_service.html", "class_w_s_d_l_1_1_web_service" ],
      [ "WSMessageHelper", "class_w_s_d_l_1_1_w_s_message_helper.html", "class_w_s_d_l_1_1_w_s_message_helper" ]
    ] ]
];

==> qore-xml-module-2.0.0.tar.bz2: qore-xml-module-2.0.0/docs/WSDL/html/annotated_dup.js <==
var annotated_dup =
[
    [ "WSDL", "namespace_w_s_d_l.html", [
      [ "ArgInfo", "struct_w_s_d_l_1_1_arg_info.html", "struct_w_s_d_l_1_1_arg_info" ],
      [ "Binding", "class_w_s_d_l_1_1_binding.html", "class_w_s_d_l_1_1_binding" ],
      [ "BindingContentDescription", "class_w_s_d_l_1_1_binding_content_description.html", "class_w_s_d_l_1_1_binding_content_description" ],
      [ "BindingMessageBodyDescription", "class_w_s_d_l_1_1_binding_message_body_description.html", "class_w_s_d_l_1_1_binding_message_body_description" ],
      [ "BindingMessageDescription", "class_w_s_d_l_1_1_binding_message_description.html", "class_w_s_d_l_1_1_binding_message_description" ],
      [ "BindingMessageHeaderDescription", "class_w_s_d_l_1_1_binding_message_header_description.html", "class_w_s_d_l_1_1_binding_message_header_description" ],
      [ "ChoiceInfo", "struct_w_s_d_l_1_1_choice_info.html", null ],
      [ "MimeXmlMessageDescription", "class_w_s_d_l_1_1_mime_xml_message_description.html", "class_w_s_d_l_1_1_mime_xml_message_description" ],
      [ "Namespaces", "class_w_s_d_l_1_1_namespaces.html", "class_w_s_d_l_1_1_namespaces" ],
      [ "OperationalBinding", "class_w_s_d_l_1_1_operational_binding.html", null ],
      [ "OperationInfo", "struct_w_s_d_l_1_1_operation_info.html", "struct_w_s_d_l_1_1_operation_info" ],
      [ "PortTypeInfo", "struct_w_s_d_l_1_1_port_type_info.html", null ],
      [ "ServiceInfo", "struct_w_s_d_l_1_1_service_info.html", "struct_w_s_d_l_1_1_service_info" ],
      [ "WebService", "class_w_s_d_l_1_1_web_service.html", "class_w_s_d_l_1_1_web_service" ],
      [ "WSDLLib", "class_w_s_d_l_1_1_w_s_d_l_lib.html", "class_w_s_d_l_1_1_w_s_d_l_lib" ],
      [ "WSMessage", "class_w_s_d_l_1_1_w_s_message.html", "class_w_s_d_l_1_1_w_s_message" ],
      [ "WSMessageHelper", "class_w_s_d_l_1_1_w_s_message_helper.html", "class_w_s_d_l_1_1_w_s_message_helper" ],
      [ "WSOperation", "class_w_s_d_l_1_1_w_s_operation.html", "class_w_s_d_l_1_1_w_s_operation" ],
      [ "XsdArrayType", "class_w_s_d_l_1_1_xsd_array_type.html", null ],
      [ "XsdAttribute", "class_w_s_d_l_1_1_xsd_attribute.html", null ],
      [ "XsdBase", "class_w_s_d_l_1_1_xsd_base.html", null ],
      [ "XsdBaseType", "class_w_s_d_l_1_1_xsd_base_type.html", null ],
      [ "XsdComplexType", "class_w_s_d_l_1_1_xsd_complex_type.html", "class_w_s_d_l_1_1_xsd_complex_type" ],
      [ "XsdData", "class_w_s_d_l_1_1_xsd_data.html", null ],
      [ "XsdElement", "class_w_s_d_l_1_1_xsd_element.html", null ],
      [ "XsdNamedData", "class_w_s_d_l_1_1_xsd_named_data.html", "class_w_s_d_l_1_1_xsd_named_data" ],
      [ "XsdSimpleType", "class_w_s_d_l_1_1_xsd_simple_type.html", null ],
      [ "XsdTypedData", "class_w_s_d_l_1_1_xsd_typed_data.html", null ]
    ] ]
];
